==> 1.0.0.zip: terraform-provider-dynamix/samples/cloudapi/disk/resource_disk_replication/main.tf <==
/*
Пример использования
Ресурс репликации диска
*/

#Раскомментируйте этот код,
#и внесите необходимые правки в версию и путь,
#чтобы работать с установленным вручную (не через hashicorp provider registry) провайдером
/*
terraform {
  required_providers {
    dynamix = {
      source  = "basistech.ru/tf/dynamix"
      version = "<VERSION>"
    }
  }
}
*/

provider "dynamix" {
  authenticator = "decs3o"
  #controller_url = <DECORT_CONTROLLER_URL>
  controller_url = "https://ds1.digitalenergy.online"
  #oauth2_url = <DECORT_SSO_URL>
  oauth2_url           = "https://sso.digitalenergy.online"
  allow_unverified_ssl = true
}

resource "dynamix_disk_replication" "dr" {
  #id диска из которого будет создана реплика
  #обязательный параметр
  #тип - целое число
  disk_id = 31606

  #имя реплики диска
  #обязательный параметр
  #тип - строка
  disk_name = "test"

  #sep id
  #обязательный параметр
  #тип - целое число
  sep_id = 1

  #название pool
  #обязательный параметр
  #тип - строка
  pool_name = "some"

  #флаг паузы
  #опциональный параметр
  #тип - булев
  #pause = false

  #флаг для изменения ролей дисков
  #опциональный параметр
  #тип - булев
  #reverse = false

  #флаг для запуска связи между диском и репликой
  #опциональный параметр
  #тип - булев
  #start = false

  #флаг для отключения диска от ВМ при удалении
  #опциональный параметр
  #тип - булев
  #detach = false

  #флаг для удаления реплики диска безвозвратно
  #опциональный параметр
  #тип - булев
  #permanently = false

  #описание причины удаления
  #опциональный параметр
  #тип - строка
  #reason = "some"
}


output "test" {
  value = dynamix_disk_replication.dr
}

==> 1.2.1.zip: terraform-provider-dynamix/samples/cloudapi/disk/resource_disk_replication/main.tf <==
/*
Пример использования
Ресурс репликации диска
*/

#Раскомментируйте этот код,
#и внесите необходимые правки в версию и путь,
#чтобы работать с установленным вручную (не через hashicorp provider registry) провайдером
/*
terraform {
  required_providers {
    dynamix = {
      source  = "basistech.ru/tf/dynamix"
      version = "<VERSION>"
    }
  }
}
*/

provider "dynamix" {
  authenticator = "decs3o"
  #controller_url = <DYNAMIX_CONTROLLER_URL>
  controller_url = "https://ds1.digitalenergy.online"
  #oauth2_url = <DYNAMIX_OAUTH2_URL>
  oauth2_url           = "https://sso.digitalenergy.online"
  allow_unverified_ssl = true
}

resource "dynamix_disk_replication" "dr" {
  #id диска из которого будет создана реплика
  #обязательный параметр
  #тип - целое число
  disk_id = 31606

  #имя реплики диска
  #обязательный параметр
  #тип - строка
  disk_name = "test"

  #sep id
  #обязательный параметр
  #тип - целое число
  sep_id = 1

  #название pool
  #обязательный параметр
  #тип - строка
  pool_name = "some"

  #флаг паузы
  #опциональный параметр
  #тип - булев
  #pause = false

  #флаг для изменения ролей дисков
  #опциональный параметр
  #тип - булев
  #reverse = false

  #флаг для запуска связи между диском и репликой
  #опциональный параметр
  #тип - булев
  #start = false

  #флаг для отключения диска от ВМ при удалении
  #опциональный параметр
  #тип - булев
  #detach = false

  #флаг для удаления реплики диска безвозвратно
  #опциональный параметр
  #тип - булев
  #permanently = false
}


output "test" {
  value = dynamix_disk_replication.dr
}
